#include "mcc_generated_files/mcc.h"

#define TIME_OFF -1     //タイマーを使用しない場合
#define TIME_UP 0       //タイムアップ
#define TIME_ADC_WAIT 10
#define TIME_ADC_ERR 50
#define LIGHT_JUDGE 0x100
#define TMEP_OVER 0xAA //30℃程度のADC値

typedef enum{
    AD_TEMP = 0,
    AD_TEMP_WAIT,
    AD_AN0,
    AD_AN0_WAIT,
    AD_AN1,
    AD_AN1_WAIT        
}ADC_MODE_NO;

/* 変数宣言*/
uint16_t tempValue;
uint16_t an0Value;
uint16_t an1Value;
int16_t timAdc;
int16_t timAdcErr;
ADC_MODE_NO adcmode;

/* プロトタイプ宣言*/
void mainTimer(void);
void AdcItr(void);
void mainApp(void);

/* Main application */
void main(void)
{
    SYSTEM_Initialize();
    TMR0_SetInterruptHandler(mainTimer);
    ADC_SetInterruptHandler(AdcItr);
    INTERRUPT_GlobalInterruptEnable();
    INTERRUPT_PeripheralInterruptEnable();

    while (1)
    {
        mainApp();
    }
}
/* タイマ管理関数 */
void mainTimer(void){
    
    if( timAdc > TIME_UP ){
        --timAdc;
    }
    
    if( timAdcErr > TIME_UP ){
        --timAdcErr;
    }
}
/* メイン処理 */
void mainApp(void){
 
    if( timAdc == TIME_UP){
        timAdc = TIME_ADC_WAIT;
        
        switch(adcmode){
            case AD_TEMP:
                ADC_SelectChannel(channel_Temp);
                ADC_StartConversion();
                adcmode = AD_TEMP_WAIT;
                break;
            case AD_TEMP_WAIT:
                //ADC変換待ち
                break;
            case AD_AN0:
                ADC_SelectChannel(channel_AN0);
                ADC_StartConversion();
                adcmode = AD_AN0_WAIT;                
                break;
            case AD_AN0_WAIT:
                //ADC変換待ち
                break;
            case AD_AN1:
                ADC_SelectChannel(channel_AN1);
                ADC_StartConversion();
                adcmode = AD_AN1_WAIT;                
                break;
            case AD_AN1_WAIT:
                //ADC変換待ち
                break;    
        }
        
        timAdcErr = TIME_ADC_ERR;
    }
    
    if( timAdcErr == TIME_UP){
        timAdcErr = TIME_OFF;
        adcmode = AD_TEMP;
    }
    
    if( an0Value >= TMEP_OVER ){
        IO_RB4_SetHigh();
    }
    else{
        IO_RB4_SetLow();
    }
    
    if( an1Value < LIGHT_JUDGE){
        IO_RB3_SetHigh();
    }
    else{
        IO_RB3_SetLow();
    }
}
/* AD変換割り込み処理 */
void AdcItr(void){
    
    switch(adcmode){
        case AD_TEMP_WAIT:
            adcmode = AD_AN0;
            tempValue = ADC_GetConversionResult(); //温度インジケーターの値
            break;
        case AD_AN0_WAIT:
            adcmode = AD_AN1;
            an0Value = ADC_GetConversionResult(); //温度センサーの値
            break;
        case AD_AN1_WAIT:
            adcmode = AD_TEMP;
            an1Value = ADC_GetConversionResult(); //照度センサーの値
            break;  
    }
    timAdcErr = TIME_OFF;
}
/**
 End of File
*/